within ;
package MOS4
  package parts

  connector PressureFlow "Pressure[mmHg] and Flow[ml/min]"
    Real pressure( final quantity="Pressure");//, final unit="mmHg");
    flow Real q( final quantity="Flow", final unit="ml/min") "flow";
    annotation (Documentation(revisions="<html>
<table>
<tr>
<td>Author:</td>
<td>Marek Matejak</td>
</tr>
<tr>
<td>Copyright:</td>
<td>In public domains</td>
</tr>
<tr>
<td>By:</td>
<td>Charles University, Prague, Czech Republic</td>
</tr>
<tr>
<td>Date of:</td>
<td>january 2009</td>
</tr>
</table>
</html>",
      info="<html>
<p><font style=\"font-size: 9pt; \">This connector connects hydraulic domains elements. The elements contains one equation for each his pressure-flow connector. The equation defines relation between variables in the connector. Variables are hydraulic pressure and volume flow of hydraulic medium. The pressure is the same in each connector that are connected together. The sum of flow in connectors connected together is zero (</font><b><font style=\"font-size: 9pt; \">Kirchhoff&apos;s circuit laws</font></b><font style=\"font-size: 9pt; \">).</font> </p>
</html>"));
  end PressureFlow;

  connector NegativePressureFlow "Pressure[mmHg] and negative Outflow[ml/min]"

    extends PressureFlow;

  annotation (
      defaultComponentName="q_out",
      Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={Rectangle(
            extent={{-20,10},{20,-10}},
            lineColor={0,0,0},
            lineThickness=1), Polygon(
            points={{0,100},{100,0},{0,-100},{-100,0},{0,100}},
            lineColor={0,0,0},
            smooth=Smooth.None,
            fillPattern=FillPattern.Solid,
            fillColor={200,200,200})}),
      Diagram(Polygon(points=[-21,-3; 5,23; 31,-3; 5,-29; -21,-3],   style(
            color=74,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0})), Text(
          extent=[-105,-38; 115,-83],
          string="%name",
          style(color=0, rgbcolor={0,0,0}))));
  end NegativePressureFlow;

  connector PositivePressureFlow "Pressure[mmHg] and Inflow[ml/min]"
    extends PressureFlow;

  annotation (
      defaultComponentName="q_in",
      Icon(coordinateSystem(preserveAspectRatio=true, extent={{-100,-100},{100,
              100}}), graphics={Rectangle(
            extent={{-20,10},{20,-10}},
            lineColor={0,0,0},
            lineThickness=1), Polygon(
            points={{0,100},{100,0},{0,-100},{-100,0},{0,100}},
            lineColor={0,0,0},
            smooth=Smooth.None,
            fillPattern=FillPattern.Solid,
            fillColor={0,0,0})}),
      Diagram(Polygon(points=[-21,-3; 5,23; 31,-3; 5,-29; -21,-3],   style(
            color=74,
            rgbcolor={0,0,0},
            fillColor=0,
            rgbfillColor={0,0,0})), Text(
          extent=[-105,-38; 115,-83],
          string="%name",
          style(color=0, rgbcolor={0,0,0}))));
  end PositivePressureFlow;

  model P
  parameter Real tlak = 0;
    NegativePressureFlow q_out
      annotation (Placement(transformation(extent={{-10,-10},{10,10}}),
          iconTransformation(extent={{-10,-10},{10,10}})));
  equation
    q_out.pressure + tlak =0;
    annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,
              -100},{100,100}}), graphics={
          Rectangle(extent={{-80,60},{60,-40}}, lineColor={0,0,255}),
          Text(
            extent={{-80,66},{62,100}},
            lineColor={0,0,255},
            textString="Pzdroj"),
          Text(
            extent={{-76,-98},{56,-44}},
            lineColor={0,0,255},
            textString="%tlak")}));
  end P;

  model Odpor

    PositivePressureFlow q_in annotation (Placement(transformation(extent={{-90,-10},
              {-70,10}}), iconTransformation(extent={{-90,-10},{-70,10}})));
    NegativePressureFlow q_out annotation (Placement(transformation(extent={{70,-10},
              {90,10}}), iconTransformation(extent={{70,-10},{90,10}})));
  parameter Real R = 1;
  Real dp;
  equation
    q_in.q + q_out.q = 0;
    dp = q_out.pressure - q_in.pressure;
    dp = R*q_in.q;
    annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,
              -100},{100,100}}), graphics={Rectangle(extent={{-60,20},{60,-20}},
              lineColor={0,0,255})}));
  end Odpor;

  model chlopen
      Real s;
      Real q;
      Boolean on;
      Real dp;
      PositivePressureFlow q_in
      annotation (Placement(transformation(extent={{-90,-10},{-70,10}})));
      NegativePressureFlow q_out
      annotation (Placement(transformation(extent={{70,-10},{90,10}})));
  equation

      dp = q_in.pressure - q_out.pressure;

      on = s > 0;
      if on then
        q = 0;
        s = dp;
      else
        dp = 0;
        s = q;
      end if;

      q_in.q + q_out.q = 0;
      annotation (Icon(coordinateSystem(preserveAspectRatio=false, extent={{-100,
                -100},{100,100}}), graphics={Polygon(
              points={{-60,60},{40,0},{-60,-60},{-60,-20},{-60,60}},
              lineColor={127,0,0},
              smooth=Smooth.None,
              fillColor={255,255,0},
              fillPattern=FillPattern.Solid), Rectangle(
              extent={{40,60},{60,-60}},
              lineColor={127,0,0},
              fillColor={255,255,0},
              fillPattern=FillPattern.Solid)}));
  end chlopen;

  model komora

    PositivePressureFlow q_in
      annotation (Placement(transformation(extent={{-10,-90},{10,-70}})));
    Modelica.Blocks.Interfaces.RealInput elastance annotation (Placement(transformation(
            extent={{-60,-32},{-20,8}}), iconTransformation(extent={{-60,-32},{-20,
              8}})));
  Real volume(start= 10);
  // initial equation
  // volume = 10;
  equation
    der(volume) = q_in.q;
    q_in.pressure = volume*elastance;
    annotation (Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-100,
              -100},{100,100}}), graphics={Ellipse(
            extent={{-60,60},{60,-80}},
            lineColor={127,0,0},
            fillColor={255,255,0},
            fillPattern=FillPattern.Solid)}), Icon(coordinateSystem(
            preserveAspectRatio=false, extent={{-100,-100},{100,100}}),
          graphics={Ellipse(
            extent={{-60,60},{60,-80}},
            lineColor={127,0,0},
            fillColor={255,255,0},
            fillPattern=FillPattern.Solid)}));
  end komora;


  end parts;
  annotation (uses(Modelica(version="3.2")));

  package tests
  end tests;

  model pumpingHeart
  end pumpingHeart;
end MOS4;
